@@ -23,9 +23,9 @@ class Sensor:
     def __init__(self, config_parser: configparser.ConfigParser):
         self.elevation = int(config_parser.get('bmp085_sensor', 'elevation'))
 
-        self.bmp085 = BMP085()
+        self.driver = BMP085()
 
     def measure(self, data_builder: DataBuilder, measurements: Measurements) -> None:
-        pressure = round(self.bmp085.read_sealevel_pressure(self.elevation) / 100, 2)
+        pressure = round(self.driver.read_sealevel_pressure(self.elevation) / 100, 2)
 
         data_builder.add("BMP085", "sea level pressure", "hPa", pressure)
